@@ -6,12 +6,12 @@ import http.cookiejar
 import json
 import logging
 import os
+import pathlib
 import random
 import shutil
 import subprocess
 import time
 import urllib
-import pathlib
 
 import aiohttp
 
@@ -73,6 +73,10 @@ def critical(msg, *args, **kwargs):
     logging.getLogger(_loggerName).critical(msg, *args, **kwargs)
 
 
+def openWindowsFolder(folder):
+    os.system(f"start explorer {folder}")
+
+
 def getPath(basePath, *parList):
     return os.path.abspath(os.path.join(basePath, *parList))
 
